Using the development buildout
==============================

Create a virtualenv in the package and install requirements with pip::

    ./bootstrap.sh

Run buildout::

    ./bin/buildout

Start Plone in foreground:

    ./bin/instance fg

